@@ -65,6 +65,9 @@ sub install {
 	my $this=shift;
 
 	my $file = "debian/bundles.properties";
+	if (!-e $file) {
+		return;
+	}
 	open(my $data, '<', $file) or die "Could not open '$file' $!\n";
 	while (my $line = <$data>) {
 		# Parse the line
